netapp_ontap.models.vscan_on_access_policy API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.vscan_on_access_policy`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VscanOnAccessPolicySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VscanOnAccessPolicy object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `enabled: bool GET POST PATCH`

    Status of the On-Access Vscan policy

  `mandatory: bool GET POST PATCH`

    Specifies if scanning is mandatory. File access is denied if there are no external virus-scanning servers available for virus scanning.

  `name: str GET POST`

    On-Access policy name

    Example: on-access-test

  `protocol: str GET POST PATCH`

    Specifies the file access protocol for the on-access policy. The following lists the possible protocols. CIFS - SMB protocol

    Valid choices:

    - cifs
  `scope: VscanOnAccessScope GET POST PATCH`

    The scope field of the vscan_on_access_policy.